import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/blocs/bloc/analytics_tab_bloc.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/widgets/analytics_communities_sidebar.dart';
import 'package:syncrow_web/pages/analytics/modules/analytics/widgets/analytics_page_tabs_and_children.dart';
import 'package:syncrow_web/pages/analytics/modules/energy_management/blocs/total_energy_consumption/total_energy_consumption_bloc.dart';
import 'package:syncrow_web/pages/analytics/services/total_energy_consumption/fake_total_energy_consumption_service.dart';
import 'package:syncrow_web/pages/device_managment/shared/navigate_home_grid_view.dart';
import 'package:syncrow_web/utils/theme/responsive_text_theme.dart';
import 'package:syncrow_web/web_layout/web_scaffold.dart';

class AnalyticsPage extends StatelessWidget {
  const AnalyticsPage({super.key});

  @override
  Widget build(BuildContext context) {
    return MultiBlocProvider(
      providers: [
        BlocProvider<AnalyticsTabBloc>(
          create: (context) => AnalyticsTabBloc(),
        ),
        BlocProvider(
          create: (context) => TotalEnergyConsumptionBloc(
            FakeTotalEnergyConsumptionService(),
          ),
        ),
      ],
      child: const AnalyticsPageForm(),
    );
  }
}

class AnalyticsPageForm extends StatelessWidget {
  const AnalyticsPageForm({super.key});

  @override
  Widget build(BuildContext context) {
    return WebScaffold(
      rightBody: const NavigateHomeGridView(),
      appBarTitle: Text(
        'Syncrow Analytics',
        style: ResponsiveTextTheme.of(context).deviceManagementTitle,
      ),
      enableMenuSidebar: false,
      scaffoldBody: const Row(
        children: [
          AnalyticsCommunitiesSidebar(),
          Expanded(flex: 5, child: AnalyticsPageTabsAndChildren()),
        ],
      ),
    );
  }
}
